import { select } from 'd3';
import { viz } from './viz';
import { data } from '@eschuman20/footballscorers';
import { observeResize } from '@curran/responsive-axes';

const yearData = data.filter((d) => d['Year'] === 2018);

export const main = (container, { state, setState }) => {
  const dimensions = observeResize({
    state,
    setState,
    container,
  });

  if (dimensions === null) return;
  const { width, height } = dimensions;

  const svg = select(container)
    .selectAll('svg')
    .data([null])
    .join('svg')
    .attr('width', width)
    .attr('height', height);

  viz(svg, {
    data: yearData,
    xValue: (d) => d.Goals,
    xAxisLabelText: 'Goals',
    xAxisLabelOffset: 38,
    yValue: (d) => d.Shots,
    yAxisLabelText: 'Shots',
    yAxisLabelOffset: 17,
    innerRectFill: '#E8E8E8',
    circleRadius: 206 / 20,
    circleOpacity: 408 / 1000,
    marginTop: 20,
    marginBottom: 50,
    marginLeft: 54,
    marginRight: 20,
    width,
    height,
    circleLabel: (d) => d['Player Names'],
    customColor: (d) => {
      switch (d.League) {
        case 'La Liga':
          return 'yellow';
        case 'Serie A':
          return 'green';
        case 'Bundesliga':
          return 'red';
        case 'Premier League':
          return 'blue';
        default:
          return 'black';
      }
    },
  });

  /*  
{
  "Country": "Spain",
  "League": "La Liga",
  "Club": "(BET)",
  "Player Names": "Juanmi Callejon",
  "Matches_Played": 19,
  "Substitution": 16,
  "Mins": 1849,
  "Goals": 11,
  "xG": 6.62,
  "xG_Per_Avg_Match": 0.34,
  "Shots": 48,
  "OnTarget": 20,
  "Shots_Per_Avg_Match": 2.47,
  "On_Target_Per_Avg_Match": 1.03,
  "Year": 2016
}
*/
};
